@@ -1,8 +1,9 @@
+# 2022.8.26  add withsi support
 # 2022.8.25  _book:booked (lem) 
 # 2022.8.19 , cp from docjson 
 # 2022.8.14 , depend on spacy3.4.1 lg model 
 import json, traceback,sys, time,  fileinput, os, en
-#ex_token = lambda t : f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" if t.text == t.text.lower() else f"{t.text}_{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}"
+from collections import Counter
 
 def _oneself( t ) :
 	from dic.oneself import oneself 
@@ -10,7 +11,7 @@ def _oneself( t ) :
 
 def kps(sid, snt, doc, with_tok:bool=False): 
 	''' 2022.8.19 '''
-	postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{_oneself(t)}"  for t in doc])
+	postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{_oneself(t)}"  for t in doc]) # uniq by ana #,'PUNCT'
 
 	_kps = []
 	[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
@@ -47,21 +48,33 @@ def kps(sid, snt, doc, with_tok:bool=False):
 	if with_tok: [ actions.append( {'_id': f"{sid}-tok-{t.i}", '_source': {"type":"tok", "src":sid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ } }) for t in doc ] 
 	return actions
 
-def kps_esjson(infile, outfile=None,  with_tok:bool=False):
+def kps_esjson(infile, outfile=None,  with_tok:bool=False,  withsi:bool=True):
 	''' gzjc.jsonlg.3.4.1.gz -> gzjc.esjson | 2022.8.19 '''
 	if outfile is None: outfile = infile.split('.json')[0] + f".esjson"
-	if os.path.exists(f"{outfile}.gz"):  os.remove(f"{outfile}.gz")
+	if os.path.exists(f"{outfile}.gz"):  #os.remove(f"{outfile}.gz")
+		print("already exists")
+		return 
 	start = time.time()
-	print ("started:", infile ,  ' -> ',  outfile, flush=True)
+	si = Counter()
+	print (f"started: {infile} -> {outfile}, withsi = {withsi}", flush=True)
 	with open(outfile, 'w') as fw: 
 		for sid, line in enumerate(fileinput.input(infile,openhook=fileinput.hook_compressed)): 
 			try:
 				arr = json.loads(line.strip())
 				doc = Doc(spacy.nlp.vocab).from_json(arr)				#res['info'] = {"tm": arr.get("timestamp",""), "url":arr.get('url','')}
 				for ar in kps(sid, doc.text, doc, with_tok):
+					if withsi: #[ si.update({kp:1}) for kp in ar['_source']['kps'] ]
+						for kp in ar['_source']['kps']:
+							si.update({kp:1})
+							akp = kp.split(':')
+							if len(akp) > 1: si.update({akp[0]:1})
+							if len(akp) > 2: si.update({f"{akp[0]}:{akp[1]}":1})
 					fw.write(json.dumps(ar) + "\n") 
 			except Exception as e:
 				print ("ex:", e, sid, line) 
+		if withsi and len(si) > 0: 
+			for s,i in si.items(): 
+				fw.write(json.dumps({'_id': s, '_source': {'s':s, 'i':i	} }) + "\n") 
 	os.system(f"gzip -f -9 {outfile}")
 	print(f"{infile} is finished, \t| using: ", time.time() - start) 
 
