@@ -24,11 +24,13 @@ config = {
 				  "type": "pattern_capture",   # add _contact_VERB as a term , => _contact_VERB with  ( _([a-z]+)_(VERB|NOUN|ADJ|ADV)
 				  "preserve_original": "false",
 				  "patterns": [
-					"(^([^_]+)_[a-z]+[,\\.$]?)",
-					"(_[a-z\\-\\.\\'\\$0-9]+)$",
-					"(_[a-z\\-\\.\\'\\$]+)",
-					"(_[^\\w]+)_",
-					"([^\\w])_"
+					#"(^([^_]+)_[a-z]+[,\\.$]?)",  
+					"(^[^_]+)",   # first lex
+					#"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)$", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
+					"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",
+					"(_[a-zA-Z,\\-\\.\\'\\$]+)",  # _^ _ADJ _, _NOUN _VERB
+					#"(_[^\\w]+)_",
+					#"([^\\w])_"
 				  ]
 				},
 				"postag_filter2": {
@@ -61,7 +63,7 @@ config = {
 				}
 			  },
 			  "analyzer": {
-				"postag_ana": {"filter": ["lowercase","postag_filter", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" },
+				"postag_ana": {"filter": ["postag_filter", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
 				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
 				"path_ana3": {"type": "custom", "tokenizer": "path-tokenizer3"},
 				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
@@ -85,10 +87,10 @@ config = {
 			 "@timestamp":{"format":"strict_date_optional_time||epoch_millis", "type":"date"},
 			"errs": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
-			"kps": { "type": "text", "analyzer": "path_ana3" ,"fielddata":"true" },
-			"pterm": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" }, # path term
-			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
-			"skenp": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
+			"kps": { "type": "text", "analyzer": "path_ana3"  },
+			"pterm": { "type": "text", "analyzer": "path_ana"  }, # path term
+			"postag": { "type": "text", "analyzer": "postag_ana"},
+			"skenp": { "type": "text", "analyzer": "postag_ana"},
 			"sentgram": { "type": "text", "analyzer": "postag_ana","fielddata":"true"}, # simple_complex_headpp compound_question_itis_svo
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
@@ -428,12 +430,32 @@ def hybchunk(hyb:str='the _NNS of', index:str='dic', size:int= -1, topk:int=10):
 		if m : si.update({ heads(m.group()):1})
 	return si.most_common(topk)
 
+def init(idxname):
+	''' init a new index '''
+	if requests.es.indices.exists(index=idxname):requests.es.indices.delete(index=idxname)
+	requests.es.indices.create(index=idxname, body=config) #, body=snt_mapping
+	print(">>finished " + idxname )
+
+def testana(index:str='test'):
+	arr = requests.post(f"http://{requests.eshost}/{index}/_analyze", json={
+  "analyzer": "postag_ana",
+  "text": "booked_,_VBD_book_VERB"
+}).json() 
+	for t in arr['tokens']:
+		print (t) 
+
 if __name__ == "__main__": 
 	#print ( sql("select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"))
 	#print ( sqlrow("show tables")) 
-	print (hybchunk(index='clec')) 
+	#print (hybchunk(index='clec')) 
+	init("test")
+	testana()
 
 '''
+{'tokens': [{'token': 'booked', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
+{'token': 'd', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
+{'token': '_book', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
+{'token': '_,', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}]}
 the_[^ ]* [^ ]*_NNS_[^ ]* of_[^ ]* 
 _^ wxpecially_wxpecially_ADV_RB the_the_DET_DT songs_song_NOUN_NNS of_of_ADP_IN _PROPN_NNP _PUNCT_.
 PUT twitter/_mapping 
@@ -561,4 +583,10 @@ GET /dic/_search
   "_source": ["postag"],
   "size":-1
 }
+
+POST /clec/_analyze
+{
+  "analyzer": "postag_ana",
+  "text": "booked_book_VBD_VERB_."
+}
 '''
\ No newline at end of file
