@@ -65,8 +65,8 @@ def corpus_stats(names:str=None, types:str="doc,snt,np,tok,trp,vp"):
 def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10): 	
 	return requests.post(f"http://{requests.eshost}/{cp}/_search/", json={"query": {  "match_phrase": { "snt": phrase }  } , "size": topk}).json()
 @app.get("/es/phrase_num", tags=["es"])
-def phrase_num(phrase:str='opened the box',  eshost:str="es.corpusly.com:9200",cp:str='clec', topk:int=10): 
-	return match_phrase(phrase, eshost, cp, topk)["hits"]["total"]["value"]
+def phrase_num(phrase:str='opened the box',  cp:str='clec', topk:int=10): 
+	return match_phrase(phrase, cp, topk)["hits"]["total"]["value"]
 
 @app.get("/es/mf", tags=["es"])
 def corpus_mf(cps:str="gzjc,clec", w:str="considered", topk:int=3):
@@ -208,6 +208,89 @@ def hybchunk(hyb:str='the _NNS of', index:str='dic', size:int= -1, topk:int=10):
 		if m : si.update({ heads(m.group()):1})
 	return si.most_common(topk)
 
+@app.get("/es/aggs", tags=["es"])
+def es_aggs(pattern:str='~dobj:door_NOUN:VERB_.*', index:str='dic', field:str='kps', size:int= 1000, asrow:bool=True):
+	''' {"key" : "~dobj:door_NOUN:VERB_open",  "doc_count" : 252} '''
+	arr = requests.post(f"http://{requests.eshost}/{index}/_search/", json={
+  "size":0,
+  "aggs": {
+    "myagg": {
+      "terms": {
+        "field": field,
+         "include": pattern , #"~dobj:door_NOUN:VERB_.*",
+         "size":size
+      }
+    }
+  }
+}).json()
+	rows = [ ( row['key'], row['doc_count'])  for row in arr['aggregations']['myagg']['buckets']]
+	return rows if asrow else [ {"key":s, "count":i} for s,i in rows ]
+
+@app.get('/es/keyness', tags=["es"])
+def es_keyness(pattern='~dobj:door_NOUN:VERB_.*', cps:str='clec', cpt:str='dic', sepa:str=None, field:str='kps', size:int= 1000): 
+	''' return (word, srccnt, tgtcnt, srcsum, tgtsum, keyness), sepa=_/:,  2022.8.25 '''
+	from util import likelihood
+	try:
+		data_src = es_aggs(pattern, cps, field, size)
+		data_tgt = es_aggs(pattern, cpt, field, size)
+
+		df = pd.DataFrame({cps: dict(data_src), cpt: dict(data_tgt)}).fillna(0)
+		df[f'{cps}_sum'] = sum([i for s,i in data_src])  # rows_count(cps) 
+		df[f'{cpt}_sum'] = sum([i for s,i in data_tgt])
+		df = df.sort_values(df.columns[0], ascending=False) #.astype(int)
+		return [ {"index": index.split(sepa)[-1] 
+		,cps:int(row[cps]),f'{cps}_sum':int(row[f'{cps}_sum'])
+		,cpt:int(row[cpt]),f'{cpt}_sum':int(row[f'{cpt}_sum']) 
+		,'keyness':likelihood(row[cps],row[cpt],row[f'{cps}_sum'],row[f'{cpt}_sum'])}  for index, row in df.iterrows()] 
+	except Exception as e:
+		print("es_keyness ex:", e) 
+		return []
+
+@app.get('/es/sntkps', tags=["es"])
+def snt_kps(text:str="She has ready. It are ok. The justice delayed is justice denied. I plan to go swimming.", did:str=None): 
+	''' parse kps for es indexing , 2022.8.26 '''
+	import hashlib,en
+	tdoc = spacy.nlp(text)
+	if did is None : did  = hashlib.md5(text.strip().lower().encode("utf-8")).hexdigest()
+	id_source = {} # used for es PUT 
+	for sid, snt in enumerate(tdoc.sents): 
+		doc = snt.as_doc() 
+		postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc])
+
+		_kps = []
+		[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
+		[ _kps.append(f"_{t.lemma_}:{t.text.lower()}") for t in doc]  # _book:booked,  added 2022.8.21
+		[ _kps.append(f"{t.tag_}:{t.pos_}_{t.lemma_}") for t in doc]  # VBD:VERB_book,  added 2022.8.25
+		[ _kps.append(f"{t.dep_}:{t.head.pos_}_{t.head.lemma_}:{t.pos_}_{t.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
+		[ _kps.append(f"~{t.dep_}:{t.pos_}_{t.lemma_}:{t.head.pos_}_{t.head.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
+		[ _kps.append(f"NP:{doc[sp.end-1].pos_}_{doc[sp.end-1].lemma_}:{sp.text.lower()}") for sp in doc.noun_chunks ]
+		_kps.append( f"stype:" +  "simple_snt" if en.simple_sent(doc) else "complex_snt" )
+		if en.compound_snt(doc) : _kps.append("stype:compound_snt")
+
+		# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
+		for lem, pos, type, chunk in en.kp_matcher(doc): #brink:NOUN:pp:on the brink
+			_kps.append(f"{type}:{pos}_{lem}:{chunk}")
+		for trpx, row in en.dep_matcher(doc): #[('svx', [1, 0, 2])] ## consider:VERB:vnpn:**** 
+			verbi = row[0] #consider:VERB:be_vbn_p:be considered as
+			_kps.append(f"{trpx}:{doc[verbi].pos_}_{doc[verbi].lemma_}")
+			if trpx == 'sva' and doc[row[0]].lemma_ == 'be': # fate is sealed, added 2022.7.25   keep sth. stuck
+				_kps.append(f"sbea:{doc[row[1]].pos_}_{doc[row[1]].lemma_}:{doc[row[2]].pos_}_{doc[row[2]].lemma_}")
+			
+		# last to be called, since NP is merged
+		for row in en.verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
+			if len(row) == 4: 
+				verbi, ibeg, iend, chunk = row
+				if doc[verbi].lemma_.isalpha() : 
+					_kps.append(f"verbnet:{doc[verbi].pos_}_{doc[verbi].lemma_}:{chunk}")
+
+		for name,ibeg,iend in en.post_np_matcher(doc): #added 2022.7.25
+			if name in ('v_n_vbn','v_n_adj'): 
+				_kps.append(f"{name}:{doc[ibeg].pos_}_{doc[ibeg].lemma_}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}")
+
+		id_source[f"{did}-{sid}"] = {'type':'snt', 'snt':snt.text.strip(), 'postag':postag,  'did':did, 'src': f"{did}-{sid}",  'tc': len(doc), 'kps': list(set(_kps)) }  
+	return id_source
+
 if __name__ == "__main__":   #uvicorn.run(app, host='0.0.0.0', port=80)
-	print ( hybchunk(index='clec'), flush=True) 
-	#uvicorn.run(app, host='0.0.0.0', port=80)
\ No newline at end of file
+	#print ( es_keyness("VERB:.*", sepa=':'), flush=True) 
+	print ( snt_kps()) 
+	uvicorn.run(app, host='0.0.0.0', port=81)
\ No newline at end of file
