@@ -40,7 +40,7 @@ def penly_xy_to_items(arr:list=[[2500,2960,3000,3160,"select-11:C"],[3500,2960,3
 	return {k:tag for x1,y1,x2,y2,tag in arr for k in xy( ( int(x1/denom), int(y1/denom), int(x2/denom), int(y2/denom)) ) }
 
 if __name__ == "__main__":  
-	print (dic_wordattr())
+	print (dualarr_keyness())
 	#uvicorn.run(app, host='0.0.0.0', port=80)
 
 '''
